==> custom_pages-v1.12.9.zip: custom_pages/messages/nl/base.php <==
<?php
return [
  '<strong>Add</strong> {templateName} item' => '<strong> Toevoegen </strong> {templateName} item',
  '<strong>Custom</strong> Pages' => '<strong>Aangepaste</strong> pagina\'s',
  '<strong>Edit</strong> snippet' => '<strong>Bewerk</strong> snipper',
  'Add' => 'Toevoegen',
  'Add a file icon before the title' => 'Voeg een bestandspictogram toe vóór de titel',
  'Additional IFrame Attributes' => 'Extra IFrame-kenmerken',
  'Adds plain HTML content to your site.' => 'Voegt eenvoudige HTML-inhoud toe aan uw site.',
  'Administrative Users' => 'Beheerdersgebruikers',
  'Advanced' => 'Geavanceerd',
  'Allows the user to manage custom pages.' => 'De gebruiker kan aangepaste pagina\'s beheren.',
  'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Hiermee kunt u pagina\'s (markdown, iframe of links) toevoegen aan de ruimtenavigatie',
  'Allows you to add content in MarkDown syntax.' => 'Hiermee kunt u inhoud toevoegen in de MarkDown-syntaxis.',
  'Alternate text' => 'Alternatieve tekst',
  'Always' => 'Altijd',
  'Always make a backup of your view files outside of your production environment!' => 'Maak altijd een back-up van uw view-bestanden buiten uw productieomgeving!',
  'An empty allowed template selection will allow all container templates for this container.' => 'Een lege toegestane sjabloonselectie staat alle containersjablonen voor deze container toe.',
  'Authors' => 'Auteurs',
  'Back' => 'Terug',
  'Back to dashboard' => 'Terug naar dashboard',
  'Back to overview' => 'Terug naar het overzicht',
  'Back to space' => 'Terug naar de ruimte',
  'Can manage custom pages' => 'Kan aangepaste pagina\'s beheren',
  'Cannot delete!' => 'Kan niet verwijderen!',
  'Category' => 'Categorie',
  'Configuration' => 'Configuratie',
  'Container' => 'Container',
  'Content' => 'Inhoud',
  'Content filters' => 'Inhoudsfilters',
  'Create' => 'Creëren',
  'Css Class' => 'CSS-klasse',
  'Custom' => 'Extra',
  'Custom Pages' => 'Aangepaste pagina\'s',
  'Custom pages' => 'Aangepaste pagina\'s',
  'Dashboard' => 'Dashboard',
  'Default' => 'Standaard',
  'Default Content' => 'Standaard inhoud',
  'Delete' => 'Verwijder',
  'Deleted.' => 'Verwijderd.',
  'Edit' => 'Bewerk',
  'Edit Page' => 'Bewerk pagina',
  'Empty' => 'Leeg',
  'Empty content elements cannot be deleted!' => 'Lege inhoudselementen kunnen niet worden verwijderd!',
  'Enter post content ID' => 'Voer de inhouds-ID van het bericht in',
  'File' => 'Bestand',
  'Footer menu' => 'Voettekstmenu',
  'General' => 'Algemeen',
  'Global Page' => 'Overal zichtbare pagina',
  'Global Widget' => 'Overal zichtbare widget',
  'Go Back' => 'Ga terug',
  'Html' => 'HTML',
  'ID' => 'ID',
  'Icon' => 'Pictogram',
  'Iframe' => 'Iframe',
  'Import' => 'Importeren',
  'Insert' => 'Invoegen',
  'Invalid request data!' => 'Ongeldige requestgegevens!',
  'Invalid template selection!' => 'Ongeldige sjabloon selectie!',
  'Invalid type selection' => 'Ongeldige typeselectie',
  'Invalid view file selection!' => 'Ongeldige view bestandsselectie!',
  'Layout' => 'Indeling',
  'Leave empty to list all records related to the current user.' => 'Laat dit veld leeg om alle records met betrekking tot de huidige gebruiker te tonen.',
  'Limit' => 'Beperken',
  'Link' => 'Link',
  'Logged-In Users' => 'Ingelogde gebruikers',
  'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => 'Beheer lay-outs, fragmentlay-outs en containers. Lay-outs definiëren paginastructuren, fragmentlay-outs worden gebruikt in zijbalken of secties, en containers zijn herbruikbare contentblokken.',
  'MarkDown' => 'Markdown',
  'Menu settings' => 'Menu-instellingen',
  'Navigation' => 'Navigatie',
  'Non-Logged-In Users' => 'Niet-ingelogde gebruikers',
  'On this page you can configure general settings of your custom pages.' => 'Op deze pagina kunt u algemene instellingen van uw aangepaste pagina\'s configureren.',
  'Overview' => 'Overzicht',
  'PHP' => 'PHP',
  'Page' => 'Pagina',
  'Page Content' => 'Pagina-inhoud',
  'Pages' => 'Pagina\'s',
  'Panel' => 'Paneel',
  'People Buttons' => 'Gebruikersknoppen',
  'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Kies een van de volgende inhoudstypen. Het inhoudstype bepaalt hoe uw inhoud wordt geplaatst in uw webpagina\\\'s.',
  'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Houd er rekening mee dat op php gebaseerde pagina\'s kwetsbaar zijn voor beveiligingsproblemen, vooral bij het omgaan met gebruikersinvoer. Raadpleeg voor meer informatie de <a href="{url}">Yii\'s Security best practices</a>.',
  'Public' => 'Openbaar',
  'Reset' => 'Reset',
  'Reset the content to default value' => 'De inhoud terugzetten naar de standaardwaarde',
  'Resources' => 'Bronnen',
  'Restrict to following comma separated content IDs' => 'Beperk tot de volgende door komma\'s gescheiden inhouds-ID\'s',
  'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Selecteer deze instelling alleen voor zichtbare tekstknooppunten. Schakel deze instelling uit als dit element bijvoorbeeld wordt gebruikt als HTML-attribuutwaarde.',
  'Settings' => 'Instellingen',
  'Show additional file information (size)' => 'Extra bestandsinformatie weergeven (grootte)',
  'Snippet' => 'Fragment',
  'Snippets' => 'Snippers',
  'Sort Order' => 'Sorteervolgorde',
  'Source' => 'Bron',
  'Space' => 'Ruimte',
  'Space Members only' => 'Alleen ruimte-leden',
  'Space Navigation' => 'Ruimte navigatie',
  'Space Page' => 'Ruimte pagina',
  'Space Widget' => 'Ruimte widget',
  'Spaces' => 'Ruimtes',
  'Start Page' => 'Startpagina',
  'Stream' => 'Berichtenstroom',
  'Stream options' => 'Stream-opties',
  'Style' => 'Stijl',
  'Style Class' => 'Stijlklasse',
  'Submit' => 'Verzenden',
  'Target Url' => 'Doel-URL',
  'Template' => 'Sjabloon',
  'Template Layout' => 'Sjabloon lay-out',
  'Templates' => 'Sjablonen',
  'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Met sjablonen kunt u combineerbare paginafragmenten definiëren met inline-bewerkingsfunctionaliteit.',
  'This container does not allow any further items!' => 'Deze container staat geen verdere items toe!',
  'Title' => 'Titel',
  'Top Navigation' => 'Hoofd navigatie',
  'Topics' => 'Rubriek',
  'Type' => 'Type',
  'Upload image' => 'Afbeelding uploaden',
  'Usage' => 'Gebruik',
  'User Account Menu (Settings)' => 'Gebruikersaccountmenu (Instellingen)',
  'Visibility' => 'Zichtbaarheid',
  'Will embed the result of a given url as an iframe element.' => 'Het resultaat van een opgegeven URL insluiten als een iframe-element.',
  'Will redirect requests to a given (relative or absolute) url.' => 'Zend verzoeken om naar een opgegeven (relatieve of absolute) URL.',
  'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Met op PHP gebaseerde pagina\'s kunt u aangepaste pagina\'s maken door middel van view-bestanden in uw bestandssysteem. Controleer de moduleconfiguratie voor meer informatie.',
  'Without adding to navigation (Direct link)' => 'Zonder toevoeging aan navigatie (directe link)',
  'Wrap this HTML page with white panel' => 'Plaats deze HTML-pagina in een wit paneel',
  'You are not allowed to delete default content!' => 'Het is niet toegestaan om standaard inhoud te verwijderen!',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/nl/base.php <==
<?php
return [
  '<strong>Add</strong> {templateName} item' => '<strong> Toevoegen </strong> {templateName} item',
  '<strong>Custom</strong> Pages' => '<strong>Aangepaste</strong> pagina\'s',
  '<strong>Edit</strong> snippet' => '<strong>Bewerk</strong> snipper',
  'Activities' => 'Activiteiten',
  'Activity' => 'Activiteit',
  'Activity content ID' => 'Activiteitsinhoud-ID',
  'Add' => 'Toevoegen',
  'Add a file icon before the title' => 'Voeg een bestandspictogram toe vóór de titel',
  'Additional IFrame Attributes' => 'Extra IFrame-kenmerken',
  'Adds plain HTML content to your site.' => 'Voegt eenvoudige HTML-inhoud toe aan uw site.',
  'Administrative Users' => 'Beheerdersgebruikers',
  'Advanced' => 'Geavanceerd',
  'Allows the user to manage custom pages.' => 'De gebruiker kan aangepaste pagina\'s beheren.',
  'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Hiermee kunt u pagina\'s (markdown, iframe of links) toevoegen aan de ruimtenavigatie',
  'Allows you to add content in MarkDown syntax.' => 'Hiermee kunt u inhoud toevoegen in de MarkDown-syntaxis.',
  'Alternate text' => 'Alternatieve tekst',
  'Always' => 'Altijd',
  'Always make a backup of your view files outside of your production environment!' => 'Maak altijd een back-up van uw view-bestanden buiten uw productieomgeving!',
  'An empty allowed template selection will allow all container templates for this container.' => 'Een lege toegestane sjabloonselectie staat alle containersjablonen voor deze container toe.',
  'Authors' => 'Auteurs',
  'Back' => 'Terug',
  'Back to dashboard' => 'Terug naar dashboard',
  'Back to overview' => 'Terug naar het overzicht',
  'Back to space' => 'Terug naar de ruimte',
  'By creation date' => 'Op aanmaakdatum',
  'By last update' => 'Laatst bijgewerkt',
  'Can manage custom pages' => 'Kan aangepaste pagina\'s beheren',
  'Cannot delete!' => 'Kan niet verwijderen!',
  'Category' => 'Categorie',
  'Configuration' => 'Configuratie',
  'Container' => 'Container',
  'Content' => 'Inhoud',
  'Content filters' => 'Inhoudsfilters',
  'Create' => 'Creëren',
  'Css Class' => 'CSS-klasse',
  'Custom' => 'Extra',
  'Custom Pages' => 'Aangepaste pagina\'s',
  'Custom pages' => 'Aangepaste pagina\'s',
  'Dashboard' => 'Dashboard',
  'Default' => 'Standaard',
  'Default Content' => 'Standaard inhoud',
  'Delete' => 'Verwijder',
  'Deleted.' => 'Verwijderd.',
  'Determine which Spaces should be taken into account.' => 'Bepaal welke ruimtes in aanmerking moeten worden genomen.',
  'Edit' => 'Bewerk',
  'Edit Page' => 'Bewerk pagina',
  'Empty' => 'Leeg',
  'Empty content elements cannot be deleted!' => 'Lege inhoudselementen kunnen niet worden verwijderd!',
  'Enter post content ID' => 'Voer de inhouds-ID van het bericht in',
  'File' => 'Bestand',
  'Footer menu' => 'Voettekstmenu',
  'General' => 'Algemeen',
  'Global Page' => 'Overal zichtbare pagina',
  'Global Widget' => 'Overal zichtbare widget',
  'Go Back' => 'Ga terug',
  'Html' => 'HTML',
  'ID' => 'ID',
  'Icon' => 'Pictogram',
  'Iframe' => 'Iframe',
  'Import' => 'Importeren',
  'Include all Spaces except selected' => 'Neem alle ruimtes mee, behalve de geselecteerde.',
  'Include selected Spaces only' => 'Alleen geselecteerde ruimtes opnemen',
  'Insert' => 'Invoegen',
  'Invalid request data!' => 'Ongeldige requestgegevens!',
  'Invalid template selection!' => 'Ongeldige sjabloon selectie!',
  'Invalid type selection' => 'Ongeldige typeselectie',
  'Invalid view file selection!' => 'Ongeldige view bestandsselectie!',
  'Layout' => 'Indeling',
  'Leave empty to list all records related to the current user.' => 'Laat dit veld leeg om alle records met betrekking tot de huidige gebruiker te tonen.',
  'Limit' => 'Beperken',
  'Link' => 'Link',
  'Logged-In Users' => 'Ingelogde gebruikers',
  'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => 'Beheer lay-outs, fragmentlay-outs en containers. Lay-outs definiëren paginastructuren, fragmentlay-outs worden gebruikt in zijbalken of secties, en containers zijn herbruikbare contentblokken.',
  'MarkDown' => 'Markdown',
  'Menu settings' => 'Menu-instellingen',
  'Navigation' => 'Navigatie',
  'Non-Logged-In Users' => 'Niet-ingelogde gebruikers',
  'On this page you can configure general settings of your custom pages.' => 'Op deze pagina kunt u algemene instellingen van uw aangepaste pagina\'s configureren.',
  'Overview' => 'Overzicht',
  'PHP' => 'PHP',
  'Page' => 'Pagina',
  'Page Content' => 'Pagina-inhoud',
  'Pages' => 'Pagina\'s',
  'Panel' => 'Paneel',
  'People Buttons' => 'Gebruikersknoppen',
  'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Kies een van de volgende inhoudstypen. Het inhoudstype bepaalt hoe uw inhoud wordt geplaatst in uw webpagina\\\'s.',
  'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Houd er rekening mee dat op php gebaseerde pagina\'s kwetsbaar zijn voor beveiligingsproblemen, vooral bij het omgaan met gebruikersinvoer. Raadpleeg voor meer informatie de <a href="{url}">Yii\'s Security best practices</a>.',
  'Public' => 'Openbaar',
  'Reset' => 'Reset',
  'Reset the content to default value' => 'De inhoud terugzetten naar de standaardwaarde',
  'Resources' => 'Bronnen',
  'Restrict to following comma separated content IDs' => 'Beperk tot de volgende door komma\'s gescheiden inhouds-ID\'s',
  'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Selecteer deze instelling alleen voor zichtbare tekstknooppunten. Schakel deze instelling uit als dit element bijvoorbeeld wordt gebruikt als HTML-attribuutwaarde.',
  'Settings' => 'Instellingen',
  'Show additional file information (size)' => 'Extra bestandsinformatie weergeven (grootte)',
  'Snippet' => 'Fragment',
  'Snippets' => 'Snippers',
  'Sort Order' => 'Sorteervolgorde',
  'Sorting' => 'Sorteren',
  'Source' => 'Bron',
  'Space' => 'Ruimte',
  'Space Members only' => 'Alleen ruimte-leden',
  'Space Navigation' => 'Ruimte navigatie',
  'Space Page' => 'Ruimte pagina',
  'Space Widget' => 'Ruimte widget',
  'Space selection' => 'Ruimte selectie',
  'Spaces' => 'Ruimtes',
  'Start Page' => 'Startpagina',
  'Stream' => 'Berichtenstroom',
  'Stream options' => 'Stream-opties',
  'Style' => 'Stijl',
  'Style Class' => 'Stijlklasse',
  'Submit' => 'Verzenden',
  'Target Url' => 'Doel-URL',
  'Template' => 'Sjabloon',
  'Template Layout' => 'Sjabloon lay-out',
  'Templates' => 'Sjablonen',
  'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Met sjablonen kunt u combineerbare paginafragmenten definiëren met inline-bewerkingsfunctionaliteit.',
  'This container does not allow any further items!' => 'Deze container staat geen verdere items toe!',
  'Title' => 'Titel',
  'Top Navigation' => 'Hoofd navigatie',
  'Topics' => 'Rubriek',
  'Type' => 'Type',
  'Upload image' => 'Afbeelding uploaden',
  'Usage' => 'Gebruik',
  'User Account Menu (Settings)' => 'Gebruikersaccountmenu (Instellingen)',
  'Visibility' => 'Zichtbaarheid',
  'Will embed the result of a given url as an iframe element.' => 'Het resultaat van een opgegeven URL insluiten als een iframe-element.',
  'Will redirect requests to a given (relative or absolute) url.' => 'Zend verzoeken om naar een opgegeven (relatieve of absolute) URL.',
  'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Met op PHP gebaseerde pagina\'s kunt u aangepaste pagina\'s maken door middel van view-bestanden in uw bestandssysteem. Controleer de moduleconfiguratie voor meer informatie.',
  'Without adding to navigation (Direct link)' => 'Zonder toevoeging aan navigatie (directe link)',
  'Wrap this HTML page with white panel' => 'Plaats deze HTML-pagina in een wit paneel',
  'You are not allowed to delete default content!' => 'Het is niet toegestaan om standaard inhoud te verwijderen!',
];
